==> highlights-0.1.0.tgz: package/lib/cli.js <==
(function() {
  var Highlights, fs, optimist, path;

  path = require('path');

  fs = require('fs-plus');

  optimist = require('optimist');

  Highlights = require('./highlights');

  module.exports = function() {
    var cli, fileContents, filePath, html, outputPath, version;
    cli = optimist.describe('h', 'Show this message').alias('h', 'help').describe('o', 'File path to write the HTML output to').alias('o', 'output').string('o').describe('s', 'Scope name of the grammar to use').alias('s', 'scope').string('s').describe('v', 'Output the version').alias('v', 'version').boolean('s');
    optimist.usage("Usage: highlights [options] [file]\n\nOutput the syntax highlighted HTML for a file.\n\nIf no file is specified then the text to highlight is read from standard in.");
    if (cli.argv.help) {
      cli.showHelp();
      return;
    }
    if (cli.argv.version) {
      version = require('../package.json').version;
      console.log(version);
      return;
    }
    filePath = cli.argv._[0];
    if (filePath) {
      filePath = path.resolve(filePath);
      if (!fs.isFileSync(filePath)) {
        console.error("Specified path is not a file: " + filePath);
        process.exit(1);
        return;
      }
      html = new Highlights().highlightSync({
        filePath: filePath,
        scopeName: cli.argv.scope
      });
      if (cli.argv.output) {
        outputPath = path.resolve(cli.argv.output);
        return fs.writeFileSync(outputPath, html);
      } else {
        return console.log(html);
      }
    } else {
      process.stdin.resume();
      process.stdin.setEncoding('utf8');
      fileContents = '';
      process.stdin.on('data', function(chunk) {
        return fileContents += chunk.toString();
      });
      return process.stdin.on('end', function() {
        html = new Highlights().highlightSync({
          fileContents: fileContents,
          scopeName: cli.argv.scope
        });
        return console.log(html);
      });
    }
  };

}).call(this);

==> highlights-0.4.0.tgz: package/lib/cli.js <==
(function() {
  var Highlights, fs, optimist, path;

  path = require('path');

  fs = require('fs-plus');

  optimist = require('optimist');

  Highlights = require('./highlights');

  module.exports = function() {
    var cli, fileContents, filePath, html, outputPath, version;
    cli = optimist.describe('h', 'Show this message').alias('h', 'help').describe('o', 'File path to write the HTML output to').alias('o', 'output').string('o').describe('s', 'Scope name of the grammar to use').alias('s', 'scope').string('s').describe('v', 'Output the version').alias('v', 'version').boolean('s');
    optimist.usage("Usage: highlights [options] [file]\n\nOutput the syntax highlighted HTML for a file.\n\nIf no file is specified then the text to highlight is read from standard in.\n\nIf no output file is specified then the HTML is written to standard out.");
    if (cli.argv.help) {
      cli.showHelp();
      return;
    }
    if (cli.argv.version) {
      version = require('../package.json').version;
      console.log(version);
      return;
    }
    filePath = cli.argv._[0];
    if (filePath) {
      filePath = path.resolve(filePath);
      if (!fs.isFileSync(filePath)) {
        console.error("Specified path is not a file: " + filePath);
        process.exit(1);
        return;
      }
      html = new Highlights().highlightSync({
        filePath: filePath,
        scopeName: cli.argv.scope
      });
      if (cli.argv.output) {
        outputPath = path.resolve(cli.argv.output);
        return fs.writeFileSync(outputPath, html);
      } else {
        return console.log(html);
      }
    } else {
      process.stdin.resume();
      process.stdin.setEncoding('utf8');
      fileContents = '';
      process.stdin.on('data', function(chunk) {
        return fileContents += chunk.toString();
      });
      return process.stdin.on('end', function() {
        html = new Highlights().highlightSync({
          fileContents: fileContents,
          scopeName: cli.argv.scope
        });
        return console.log(html);
      });
    }
  };

}).call(this);
